@@ -12,8 +12,8 @@
 #elif defined(__WXOSX__)
 #include <OpenGL/gl.h>
 #include <OpenGL/glu.h>
-typedef void (*  _GLUfuncptr)();
-#define GL_COMPRESSED_RGB_FXT1_3DFX       0x86B0
+typedef void (*_GLUfuncptr)();
+#define GL_COMPRESSED_RGB_FXT1_3DFX 0x86B0
 
 #elif defined(__WXQT__) || defined(__WXGTK__)
 #include <GL/glew.h>
@@ -21,7 +21,6 @@ typedef void (*  _GLUfuncptr)();
 #endif  // ocpnUSE_GL
 #endif
 
-
 #include <wx/colour.h>
 #include <wx/gdicmn.h>
 #include <wx/pen.h>
@@ -48,18 +47,17 @@ typedef void (*  _GLUfuncptr)();
 #include "viewport.h"
 #include "waypointman_gui.h"
 
-
-extern Multiplexer* g_pMUX;
+extern Multiplexer *g_pMUX;
 extern ocpnGLOptions g_GLOptions;
 extern float g_MarkScaleFactorExp;
-extern MyFrame* gFrame;
-extern OCPNPlatform* g_Platform;
-extern ocpnStyle::StyleManager* g_StyleManager;
+extern MyFrame *gFrame;
+extern OCPNPlatform *g_Platform;
+extern ocpnStyle::StyleManager *g_StyleManager;
 
-extern Routeman* g_pRouteMan;
+extern Routeman *g_pRouteMan;
 
-void RoutePointGui::Draw(ocpnDC& dc, ChartCanvas* canvas, wxPoint* rpn,
-                         bool boverride_viz)  {
+void RoutePointGui::Draw(ocpnDC &dc, ChartCanvas *canvas, wxPoint *rpn,
+                         bool boverride_viz) {
   wxPoint r;
   wxRect hilitebox;
 
@@ -68,24 +66,21 @@ void RoutePointGui::Draw(ocpnDC& dc, ChartCanvas* canvas, wxPoint* rpn,
   //  return the home point in this dc to allow "connect the dots"
   if (NULL != rpn) *rpn = r;
 
-  if (!RoutePointGui(m_point).IsVisibleSelectable(canvas, boverride_viz)) return;
+  if (!RoutePointGui(m_point).IsVisibleSelectable(canvas, boverride_viz))
+    return;
 
   // If waypoint is well off screen, skip the drawing
-  if( (abs(r.x) > canvas->GetCanvasWidth() * 4 ) ||
+  if ((abs(r.x) > canvas->GetCanvasWidth() * 4) ||
       (abs(r.y) > canvas->GetCanvasHeight() * 4))
     return;
 
   // If waypoint pixel location is invalid, skip the drawing
-  if ((abs(r.x) == INVALID_COORD ) ||
-      (abs(r.y) == INVALID_COORD) )
-  return;
-
-
+  if ((abs(r.x) == INVALID_COORD) || (abs(r.y) == INVALID_COORD)) return;
 
   //    Optimization, especially apparent on tracks in normal cases
-  if (m_point.m_IconName == _T("empty") && !m_point.m_bShowName
-       && !m_point.m_bPtIsSelected){
-      return;
+  if (m_point.m_IconName == _T("empty") && !m_point.m_bShowName &&
+      !m_point.m_bPtIsSelected) {
+    return;
   }
 
   wxPen *pen;
@@ -129,16 +124,17 @@ void RoutePointGui::Draw(ocpnDC& dc, ChartCanvas* canvas, wxPoint* rpn,
       font_size /= OCPN_GetWinDIPScaleFactor();
 
       m_point.m_pMarkFont = FontMgr::Get().FindOrCreateFont(
-        font_size, dFont->GetFamily(), dFont->GetStyle(), dFont->GetWeight(),
-        false, dFont->GetFaceName());
+          font_size, dFont->GetFamily(), dFont->GetStyle(), dFont->GetWeight(),
+          false, dFont->GetFaceName());
 
       m_point.m_FontColor = FontMgr::Get().GetFontColor(_("Marks"));
       m_point.CalculateNameExtents();
     }
 
     if (m_point.m_pMarkFont) {
-      wxRect r2(r.x + m_point.m_NameLocationOffsetX, r.y + m_point.m_NameLocationOffsetY,
-                m_point.m_NameExtents.x, m_point.m_NameExtents.y);
+      wxRect r2(r.x + m_point.m_NameLocationOffsetX,
+                r.y + m_point.m_NameLocationOffsetY, m_point.m_NameExtents.x,
+                m_point.m_NameExtents.y);
       r1.Union(r2);
     }
   }
@@ -191,7 +187,8 @@ void RoutePointGui::Draw(ocpnDC& dc, ChartCanvas* canvas, wxPoint* rpn,
   }
 
   // Draw waypoint radar rings if activated
-  if (m_point.m_iWaypointRangeRingsNumber && m_point.m_bShowWaypointRangeRings) {
+  if (m_point.m_iWaypointRangeRingsNumber &&
+      m_point.m_bShowWaypointRangeRings) {
     double factor = 1.00;
     if (m_point.m_iWaypointRangeRingsStepUnits == 1)  // nautical miles
       factor = 1 / 1.852;
@@ -211,8 +208,8 @@ void RoutePointGui::Draw(ocpnDC& dc, ChartCanvas* canvas, wxPoint* rpn,
     wxBrush saveBrush = dc.GetBrush();
     wxPen savePen = dc.GetPen();
     dc.SetPen(ppPen1);
-    dc.SetBrush(
-        wxBrush(m_point.m_wxcWaypointRangeRingsColour, wxBRUSHSTYLE_TRANSPARENT));
+    dc.SetBrush(wxBrush(m_point.m_wxcWaypointRangeRingsColour,
+                        wxBRUSHSTYLE_TRANSPARENT));
 
     for (int i = 1; i <= m_point.m_iWaypointRangeRingsNumber; i++)
       dc.StrokeCircle(r.x, r.y, i * pix_radius);
@@ -239,17 +236,22 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
   if (!RoutePointGui(m_point).IsVisibleSelectable(canvas, bVizOverride)) return;
 
   //    Optimization, especially apparent on tracks in normal cases
-  if (m_point.m_IconName == _T("empty") && !m_point.m_bShowName && !m_point.m_bPtIsSelected) return;
+  if (m_point.m_IconName == _T("empty") && !m_point.m_bShowName &&
+      !m_point.m_bPtIsSelected)
+    return;
 
-  if (m_point.m_wpBBox.GetValid() && vp.view_scale_ppm == m_point.m_wpBBox_view_scale_ppm &&
+  if (m_point.m_wpBBox.GetValid() &&
+      vp.view_scale_ppm == m_point.m_wpBBox_view_scale_ppm &&
       vp.rotation == m_point.m_wpBBox_rotation) {
     /* see if this waypoint can intersect with bounding box */
     LLBBox vpBBox = vp.GetBBox();
     if (vpBBox.IntersectOut(m_point.m_wpBBox)) {
       // Are Range Rings enabled?
-      if (m_point.m_bShowWaypointRangeRings && (m_point.m_iWaypointRangeRingsNumber > 0)) {
+      if (m_point.m_bShowWaypointRangeRings &&
+          (m_point.m_iWaypointRangeRingsNumber > 0)) {
         double factor = 1.00;
-        if (m_point.m_iWaypointRangeRingsStepUnits == 1)  // convert kilometers to NMi
+        if (m_point.m_iWaypointRangeRingsStepUnits ==
+            1)  // convert kilometers to NMi
           factor = 1 / 1.852;
 
         double radius = factor * m_point.m_iWaypointRangeRingsNumber *
@@ -301,8 +303,8 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
       font_size /= OCPN_GetWinDIPScaleFactor();
 
       m_point.m_pMarkFont = FontMgr::Get().FindOrCreateFont(
-        font_size, dFont->GetFamily(), dFont->GetStyle(), dFont->GetWeight(),
-        false, dFont->GetFaceName());
+          font_size, dFont->GetFamily(), dFont->GetStyle(), dFont->GetWeight(),
+          false, dFont->GetFaceName());
 
       m_point.m_FontColor = FontMgr::Get().GetFontColor(_("Marks"));
       if (m_point.m_iTextTexture) {
@@ -314,8 +316,9 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
     }
 
     if (m_point.m_pMarkFont) {
-      wxRect r2(r.x + m_point.m_NameLocationOffsetX, r.y + m_point.m_NameLocationOffsetY,
-                m_point.m_NameExtents.x, m_point.m_NameExtents.y);
+      wxRect r2(r.x + m_point.m_NameLocationOffsetX,
+                r.y + m_point.m_NameLocationOffsetY, m_point.m_NameExtents.x,
+                m_point.m_NameExtents.y);
       r3.Union(r2);
     }
   }
@@ -341,7 +344,8 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
   }
 
   /* update bounding box */
-  if (!m_point.m_wpBBox.GetValid() || vp.view_scale_ppm != m_point.m_wpBBox_view_scale_ppm ||
+  if (!m_point.m_wpBBox.GetValid() ||
+      vp.view_scale_ppm != m_point.m_wpBBox_view_scale_ppm ||
       vp.rotation != m_point.m_wpBBox_rotation) {
     double lat1, lon1, lat2, lon2;
     canvas->GetCanvasPixPoint(r.x + hilitebox.x,
@@ -361,7 +365,7 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
   //    if(region.Contains(r3) == wxOutRegion)
   //        return;
 
-  //ocpnDC dc;
+  // ocpnDC dc;
 
   //  Highlite any selected point
   if (m_point.m_bPtIsSelected) {
@@ -384,7 +388,7 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
   if ((!bDrawHL) && (NULL != m_point.m_pbmIcon)) {
     int glw, glh;
     unsigned int IconTexture =
-       WayPointmanGui(*pWayPointMan).GetIconTexture(pbm, glw, glh);
+        WayPointmanGui(*pWayPointMan).GetIconTexture(pbm, glw, glh);
 
     glBindTexture(GL_TEXTURE_2D, IconTexture);
 
@@ -524,7 +528,8 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
       m_point.m_iTextTextureWidth = NextPow2(w);
       m_point.m_iTextTextureHeight = NextPow2(h);
       glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, m_point.m_iTextTextureWidth,
-                   m_point.m_iTextTextureHeight, 0, GL_RGBA, GL_UNSIGNED_BYTE, NULL);
+                   m_point.m_iTextTextureHeight, 0, GL_RGBA, GL_UNSIGNED_BYTE,
+                   NULL);
       glTexSubImage2D(GL_TEXTURE_2D, 0, 0, 0, w, h, GL_RGBA, GL_UNSIGNED_BYTE,
                       data);
 
@@ -544,7 +549,8 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
       glEnable(GL_TEXTURE_2D);
       glEnable(GL_BLEND);
 
-      int x = r.x + m_point.m_NameLocationOffsetX, y = r.y + m_point.m_NameLocationOffsetY;
+      int x = r.x + m_point.m_NameLocationOffsetX,
+          y = r.y + m_point.m_NameLocationOffsetY;
       float u = (float)w / m_point.m_iTextTextureWidth,
             v = (float)h / m_point.m_iTextTextureHeight;
       float coords[8];
@@ -576,7 +582,8 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
   }
 
   // Draw waypoint radar rings if activated
-  if (m_point.m_iWaypointRangeRingsNumber && m_point.m_bShowWaypointRangeRings) {
+  if (m_point.m_iWaypointRangeRingsNumber &&
+      m_point.m_bShowWaypointRangeRings) {
     double factor = 1.00;
     if (m_point.m_iWaypointRangeRingsStepUnits == 1)  // nautical miles
       factor = 1 / 1.852;
@@ -596,8 +603,8 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
     wxColor ring_dim_color = GetDimColor(m_point.m_wxcWaypointRangeRingsColour);
 
     // 0.5 mm nominal, but not less than 1 pixel
-    double platform_pen_width = wxRound(
-        wxMax(1.0, g_Platform->GetDisplayDPmm() / 2));
+    double platform_pen_width =
+        wxRound(wxMax(1.0, g_Platform->GetDisplayDPmm() / 2));
     wxPen ppPen1(ring_dim_color, platform_pen_width);
     wxBrush saveBrush = dc.GetBrush();
     wxPen savePen = dc.GetPen();
@@ -621,13 +628,15 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
     wxPen ppPen1(dh_color, 3 * platform_pen_width);
     dc.SetPen(ppPen1);
     dc.DrawLine(r.x + hilitebox.width / 4, r.y + hilitebox.height / 4,
-                r.x + m_point.m_drag_line_length_man, r.y + m_point.m_drag_line_length_man);
+                r.x + m_point.m_drag_line_length_man,
+                r.y + m_point.m_drag_line_length_man);
 
     dh_color = wxColor(0, 0, 0);
     wxPen ppPen2(dh_color, platform_pen_width);
     dc.SetPen(ppPen2);
     dc.DrawLine(r.x + hilitebox.width / 4, r.y + hilitebox.height / 4,
-                r.x + m_point.m_drag_line_length_man, r.y + m_point.m_drag_line_length_man);
+                r.x + m_point.m_drag_line_length_man,
+                r.y + m_point.m_drag_line_length_man);
 
     // The drag handle
     glBindTexture(GL_TEXTURE_2D, m_point.m_dragIconTexture);
@@ -635,8 +644,9 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
     glEnable(GL_TEXTURE_2D);
     glEnable(GL_BLEND);
 
-    int x = r.x + m_point.m_drag_icon_offset, y = r.y + m_point.m_drag_icon_offset,
-        w = m_point.m_dragIcon.GetWidth(), h = m_point.m_dragIcon.GetHeight();
+    int x = r.x + m_point.m_drag_icon_offset,
+        y = r.y + m_point.m_drag_icon_offset, w = m_point.m_dragIcon.GetWidth(),
+        h = m_point.m_dragIcon.GetHeight();
 
     float scale = 1.0;
 
@@ -675,7 +685,7 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
   }
 
   if (m_point.m_bBlink)
-    g_blink_rect =m_point. CurrentRect_in_DC;  // also save for global blinker
+    g_blink_rect = m_point.CurrentRect_in_DC;  // also save for global blinker
 
   //    This will be useful for fast icon redraws
   m_point.CurrentRect_in_DC.x = r.x + hilitebox.x;
@@ -688,7 +698,8 @@ void RoutePointGui::DrawGL(ViewPort &vp, ChartCanvas *canvas, ocpnDC &dc,
 }
 #endif
 
-void RoutePointGui::CalculateDCRect(wxDC &dc, ChartCanvas *canvas, wxRect *prect) {
+void RoutePointGui::CalculateDCRect(wxDC &dc, ChartCanvas *canvas,
+                                    wxRect *prect) {
   if (canvas) {
     dc.ResetBoundingBox();
     dc.DestroyClippingRegion();
@@ -707,8 +718,8 @@ void RoutePointGui::CalculateDCRect(wxDC &dc, ChartCanvas *canvas, wxRect *prect
   }
 }
 
-bool RoutePointGui::IsVisibleSelectable(ChartCanvas* cc, bool boverrideViz) {
-    return m_point.IsVisibleSelectable(cc->GetScaleValue(), boverrideViz);
+bool RoutePointGui::IsVisibleSelectable(ChartCanvas *cc, bool boverrideViz) {
+  return m_point.IsVisibleSelectable(cc->GetScaleValue(), boverrideViz);
 }
 
 wxPoint2DDouble RoutePointGui::GetDragHandlePoint(ChartCanvas *canvas) {
@@ -723,8 +734,8 @@ void RoutePointGui::SetPointFromDraghandlePoint(ChartCanvas *canvas, double lat,
   wxPoint r;
   canvas->GetCanvasPointPix(lat, lon, &r);
   double tlat, tlon;
-  canvas->GetCanvasPixPoint(r.x - m_point.m_drag_icon_offset, r.y - m_point.m_drag_icon_offset,
-                            tlat, tlon);
+  canvas->GetCanvasPixPoint(r.x - m_point.m_drag_icon_offset,
+                            r.y - m_point.m_drag_icon_offset, tlat, tlon);
   m_point.m_lat = tlat;
   m_point.m_lon = tlon;
 }
@@ -732,9 +743,9 @@ void RoutePointGui::SetPointFromDraghandlePoint(ChartCanvas *canvas, double lat,
 void RoutePointGui::SetPointFromDraghandlePoint(ChartCanvas *canvas, int x,
                                                 int y) {
   double tlat, tlon;
-  canvas->GetCanvasPixPoint(x - m_point.m_drag_icon_offset - m_point.m_draggingOffsetx,
-                            y - m_point.m_drag_icon_offset - m_point.m_draggingOffsety, tlat,
-                            tlon);
+  canvas->GetCanvasPixPoint(
+      x - m_point.m_drag_icon_offset - m_point.m_draggingOffsetx,
+      y - m_point.m_drag_icon_offset - m_point.m_draggingOffsety, tlat, tlon);
   m_point.m_lat = tlat;
   m_point.m_lon = tlon;
 }
@@ -751,8 +762,8 @@ wxPoint2DDouble RoutePointGui::computeDragHandlePoint(ChartCanvas *canvas) {
   wxPoint r;
   canvas->GetCanvasPointPix(m_point.m_lat, m_point.m_lon, &r);
   double lat, lon;
-  canvas->GetCanvasPixPoint(r.x + m_point.m_drag_icon_offset, r.y + m_point.m_drag_icon_offset,
-                            lat, lon);
+  canvas->GetCanvasPixPoint(r.x + m_point.m_drag_icon_offset,
+                            r.y + m_point.m_drag_icon_offset, lat, lon);
 
   // Keep the members updated
   m_point.m_dragHandleLat = lat;
@@ -767,8 +778,8 @@ void RoutePointGui::ShowScaleWarningMessage(ChartCanvas *canvas) {
   wxString strC =
       _("Therefore the new waypoint will not be visible at this zoom level.");
   wxString MessStr =
-      wxString::Format(_T("%s %li,\n %s %.0f.\n%s"), strA, m_point.GetScaMin(), strB,
-                       canvas->GetScaleValue(), strC);
+      wxString::Format(_T("%s %li,\n %s %.0f.\n%s"), strA, m_point.GetScaMin(),
+                       strB, canvas->GetScaleValue(), strC);
   OCPNMessageBox(canvas, MessStr);
 }
 
@@ -781,11 +792,11 @@ void RoutePointGui::EnableDragHandle(bool bEnable) {
       int bm_size = g_Platform->GetDisplayDPmm() * 9;  // 9 mm nominal
 
       // What icon?
-      wxString UserIconPath = g_Platform->GetSharedDataDir()
-                              + _T("uidata") + wxFileName::GetPathSeparator();
+      wxString UserIconPath = g_Platform->GetSharedDataDir() + _T("uidata") +
+                              wxFileName::GetPathSeparator();
 
       m_point.m_dragIcon = LoadSVG(UserIconPath + _T("DragHandle.svg"), bm_size,
-                           bm_size, m_point.m_pbmIcon);
+                                   bm_size, m_point.m_pbmIcon);
 
       // build a texture
 #ifdef ocpnUSE_GL
@@ -829,8 +840,8 @@ void RoutePointGui::EnableDragHandle(bool bEnable) {
         }
 
         glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, m_point.m_dragIconTextureWidth,
-                     m_point.m_dragIconTextureHeight, 0, GL_RGBA, GL_UNSIGNED_BYTE,
-                     NULL);
+                     m_point.m_dragIconTextureHeight, 0, GL_RGBA,
+                     GL_UNSIGNED_BYTE, NULL);
         glTexSubImage2D(GL_TEXTURE_2D, 0, 0, 0, w, h, GL_RGBA, GL_UNSIGNED_BYTE,
                         e);
 
@@ -873,7 +884,8 @@ void RoutePointGui::ReLoadIcon(void) {
           wxBitmap bmp = style->GetIcon(_T("circle"));
           if (bmp.IsOk()) {
             wxImage image = bmp.ConvertToImage();
-            WayPointmanGui(*pWayPointMan).ProcessIcon(image, "tempsub", "tempsub");
+            WayPointmanGui(*pWayPointMan)
+                .ProcessIcon(image, "tempsub", "tempsub");
           }
         }
       }
@@ -896,7 +908,6 @@ void RoutePointGui::ReLoadIcon(void) {
 }
 
 bool RoutePointGui::SendToGPS(const wxString &com_name, SendToGpsDlg *dialog) {
-
   N0183DlgCtx dlg_ctx = GetDialogCtx(dialog);
   ::wxBeginBusyCursor();
   int result = SendWaypointToGPS_N0183(&m_point, com_name, *g_pMUX, dlg_ctx);
@@ -920,7 +931,8 @@ bool RoutePointGui::SendToGPS(const wxString &com_name, SendToGpsDlg *dialog) {
 int RoutePointGui::GetIconImageIndex() {
   if (m_point.IsShared()) {
     //    Get an array of all routes using this point
-    wxArrayPtrVoid *proute_array = g_pRouteMan->GetRouteArrayContaining(&m_point);
+    wxArrayPtrVoid *proute_array =
+        g_pRouteMan->GetRouteArrayContaining(&m_point);
 
     // Use route array (if any) to determine actual visibility for this point
     bool brp_viz = false;
