@@ -133,7 +133,7 @@ ViewPort::ViewPort() {
   m_projection_type = PROJECTION_MERCATOR;
 }
 
-void ViewPort::PixelScale(float scale){
+void ViewPort::PixelScale(float scale) {
   pix_width *= scale;
   pix_height *= scale;
   view_scale_ppm *= scale;
@@ -142,8 +142,8 @@ void ViewPort::PixelScale(float scale){
 // TODO: eliminate the use of this function
 wxPoint ViewPort::GetPixFromLL(double lat, double lon) {
   wxPoint2DDouble p = GetDoublePixFromLL(lat, lon);
-  if (wxFinite(p.m_x) && wxFinite(p.m_y)){
-    if( (abs(p.m_x) < 1e6) && (abs(p.m_y) < 1e6) )
+  if (wxFinite(p.m_x) && wxFinite(p.m_y)) {
+    if ((abs(p.m_x) < 1e6) && (abs(p.m_y) < 1e6))
       return wxPoint(wxRound(p.m_x), wxRound(p.m_y));
   }
   return wxPoint(INVALID_COORD, INVALID_COORD);
@@ -355,7 +355,7 @@ LLRegion ViewPort::GetLLRegion(const OCPNRegion &region) {
 
     int x1 = rect.x, y1 = rect.y, x2 = x1 + rect.width, y2 = y1 + rect.height;
     int p[8] = {x1, y1, x2, y1, x2, y2, x1, y2};
-    double pll[2896];     //  Max splits is 180, ((180 *  2)  + 2) * 8 = 2896.
+    double pll[2896];  //  Max splits is 180, ((180 *  2)  + 2) * 8 = 2896.
     int j;
 
     /* if the viewport is rotated, we must split the segments as straight lines
@@ -963,11 +963,10 @@ void ViewPort::SetBBoxDirect(double latmin, double lonmin, double latmax,
                              double lonmax) {
   vpBBox.Set(latmin, lonmin, latmax, lonmax);
 }
-bool ViewPort::ContainsIDL(){
+bool ViewPort::ContainsIDL() {
   if ((vpBBox.GetMinLon() <= -180.) && (vpBBox.GetMaxLon() > -180.))
     return true;
-  if ((vpBBox.GetMinLon() <= 180.) && (vpBBox.GetMaxLon() > 180.))
-    return true;
+  if ((vpBBox.GetMinLon() <= 180.) && (vpBBox.GetMaxLon() > 180.)) return true;
   return false;
 }
 
@@ -982,12 +981,10 @@ ViewPort ViewPort::BuildExpandedVP(int width, int height) {
 }
 
 void ViewPort::SetVPTransformMatrix() {
-   mat4x4 m;
-   mat4x4_identity(m);
-   mat4x4_scale_aniso((float(*)[4])vp_matrix_transform, m,
-                      2.0 / (float)pix_width, -2.0 / (float)pix_height,
-                      1.0);
-   mat4x4_translate_in_place((float(*)[4])vp_matrix_transform, -pix_width / 2,
-                             -pix_height / 2, 0);
-
+  mat4x4 m;
+  mat4x4_identity(m);
+  mat4x4_scale_aniso((float(*)[4])vp_matrix_transform, m,
+                     2.0 / (float)pix_width, -2.0 / (float)pix_height, 1.0);
+  mat4x4_translate_in_place((float(*)[4])vp_matrix_transform, -pix_width / 2,
+                            -pix_height / 2, 0);
 }
