@@ -41,7 +41,6 @@
 #include "model/geodesic.h"
 #include "model/own_ship.h"
 
-
 bool CommDecoder::ParsePosition(const LATLONG& Position, double& lat,
                                 double& lon) {
   bool ll_valid = true;
@@ -181,7 +180,8 @@ bool CommDecoder::DecodeVTG(std::string s, NavData& temp_data) {
 
   // FIXME (dave)if (g_own_ship_sog_cog_calc) return false;
 
-  if (!std::isnan(m_NMEA0183.Vtg.SpeedKnots)) temp_data.gSog = m_NMEA0183.Vtg.SpeedKnots;
+  if (!std::isnan(m_NMEA0183.Vtg.SpeedKnots))
+    temp_data.gSog = m_NMEA0183.Vtg.SpeedKnots;
 
   if (!std::isnan(m_NMEA0183.Vtg.SpeedKnots) &&
       !std::isnan(m_NMEA0183.Vtg.TrackDegreesTrue)) {
@@ -250,13 +250,12 @@ bool CommDecoder::DecodeGGA(std::string s, NavData& temp_data) {
   return true;
 }
 
-
 //---------------------------------------------------------------------
 // NMEA2000 PGN Decode
 //---------------------------------------------------------------------
 
-bool CommDecoder::DecodePGN129026(std::vector<unsigned char> v,  NavData& temp_data) {
-
+bool CommDecoder::DecodePGN129026(std::vector<unsigned char> v,
+                                  NavData& temp_data) {
   unsigned char SID;
   tN2kHeadingReference ref;
   double COG, SOG;
@@ -271,7 +270,8 @@ bool CommDecoder::DecodePGN129026(std::vector<unsigned char> v,  NavData& temp_d
   return false;
 }
 
-bool CommDecoder::DecodePGN129029(std::vector<unsigned char> v,  NavData& temp_data) {
+bool CommDecoder::DecodePGN129029(std::vector<unsigned char> v,
+                                  NavData& temp_data) {
   unsigned char SID;
   uint16_t DaysSince1970;
   double SecondsSinceMidnight;
@@ -285,13 +285,11 @@ bool CommDecoder::DecodePGN129029(std::vector<unsigned char> v,  NavData& temp_d
   uint16_t ReferenceSationID;
   double AgeOfCorrection;
 
-  if (ParseN2kPGN129029(v, SID, DaysSince1970, SecondsSinceMidnight,
-                        Latitude, Longitude, Altitude,
-                        GNSStype, GNSSmethod,
-                        nSatellites, HDOP, PDOP, GeoidalSeparation,
-                        nReferenceStations, ReferenceStationType, ReferenceSationID,
-                        AgeOfCorrection
-                        )) {
+  if (ParseN2kPGN129029(v, SID, DaysSince1970, SecondsSinceMidnight, Latitude,
+                        Longitude, Altitude, GNSStype, GNSSmethod, nSatellites,
+                        HDOP, PDOP, GeoidalSeparation, nReferenceStations,
+                        ReferenceStationType, ReferenceSationID,
+                        AgeOfCorrection)) {
     temp_data.gLat = Latitude;
     temp_data.gLon = Longitude;
     temp_data.SID = SID;
@@ -300,11 +298,9 @@ bool CommDecoder::DecodePGN129029(std::vector<unsigned char> v,  NavData& temp_d
     //  One supposes that PGN 129540 should be used instead
     //  Here we decide that if a fix is valid, nSatellites must be > 0 to be
     //  reported in this PGN 129029
-    if ( (GNSSmethod == N2kGNSSm_GNSSfix) ||
-         (GNSSmethod == N2kGNSSm_DGNSS) ||
-         (GNSSmethod == N2kGNSSm_PreciseGNSS)){
-      if (nSatellites > 0)
-        temp_data.n_satellites = nSatellites;
+    if ((GNSSmethod == N2kGNSSm_GNSSfix) || (GNSSmethod == N2kGNSSm_DGNSS) ||
+        (GNSSmethod == N2kGNSSm_PreciseGNSS)) {
+      if (nSatellites > 0) temp_data.n_satellites = nSatellites;
     }
 
     return true;
@@ -313,13 +309,13 @@ bool CommDecoder::DecodePGN129029(std::vector<unsigned char> v,  NavData& temp_d
   return false;
 }
 
-bool CommDecoder::DecodePGN127250(std::vector<unsigned char> v,  NavData& temp_data) {
-
+bool CommDecoder::DecodePGN127250(std::vector<unsigned char> v,
+                                  NavData& temp_data) {
   unsigned char SID;
   double Heading, Deviation, Variation;
   tN2kHeadingReference ref;
 
-  if (ParseN2kPGN127250(v, SID, Heading, Deviation, Variation, ref)){
+  if (ParseN2kPGN127250(v, SID, Heading, Deviation, Variation, ref)) {
     temp_data.gHdt = N2kDoubleNA;
     temp_data.gHdm = N2kDoubleNA;
     if (ref == tN2kHeadingReference::N2khr_true)
@@ -335,12 +331,11 @@ bool CommDecoder::DecodePGN127250(std::vector<unsigned char> v,  NavData& temp_d
   return false;
 }
 
-bool CommDecoder::DecodePGN129025(std::vector<unsigned char> v,  NavData& temp_data) {
-
+bool CommDecoder::DecodePGN129025(std::vector<unsigned char> v,
+                                  NavData& temp_data) {
   double Latitude, Longitude;
 
-  if (ParseN2kPGN129025(v, Latitude, Longitude)){
-
+  if (ParseN2kPGN129025(v, Latitude, Longitude)) {
     temp_data.gLat = Latitude;
     temp_data.gLon = Longitude;
     return true;
@@ -349,10 +344,11 @@ bool CommDecoder::DecodePGN129025(std::vector<unsigned char> v,  NavData& temp_d
   return false;
 }
 
-bool CommDecoder::DecodePGN129540(std::vector<unsigned char> v,  NavData& temp_data) {
-
+bool CommDecoder::DecodePGN129540(std::vector<unsigned char> v,
+                                  NavData& temp_data) {
   unsigned char SID;
-  uint8_t NumberOfSVs;;
+  uint8_t NumberOfSVs;
+  ;
   tN2kRangeResidualMode Mode;
 
   if (ParseN2kPGN129540(v, SID, Mode, NumberOfSVs)) {
@@ -364,15 +360,15 @@ bool CommDecoder::DecodePGN129540(std::vector<unsigned char> v,  NavData& temp_d
   return false;
 }
 
-bool CommDecoder::DecodeSignalK(std::string s, NavData& temp_data){
+bool CommDecoder::DecodeSignalK(std::string s, NavData& temp_data) {
   rapidjson::Document root;
 
   root.Parse(s);
-  if (root.HasParseError())
-    return false;
+  if (root.HasParseError()) return false;
 
   if (root.HasMember("updates") && root["updates"].IsArray()) {
-    for (rapidjson::Value::ConstValueIterator itr = root["updates"].Begin(); itr != root["updates"].End(); ++itr) {
+    for (rapidjson::Value::ConstValueIterator itr = root["updates"].Begin();
+         itr != root["updates"].End(); ++itr) {
       handleUpdate(*itr, temp_data);
     }
   }
@@ -380,7 +376,8 @@ bool CommDecoder::DecodeSignalK(std::string s, NavData& temp_data){
   return true;
 }
 
-void CommDecoder::handleUpdate(const rapidjson::Value &update, NavData& temp_data) {
+void CommDecoder::handleUpdate(const rapidjson::Value& update,
+                               NavData& temp_data) {
   wxString sfixtime = "";
 
   if (update.HasMember("timestamp")) {
@@ -391,17 +388,18 @@ void CommDecoder::handleUpdate(const rapidjson::Value &update, NavData& temp_dat
   }
 
   if (update.HasMember("values") && update["values"].IsArray()) {
-    for (rapidjson::Value::ConstValueIterator itr = update["values"].Begin(); itr != update["values"].End(); ++itr) {
+    for (rapidjson::Value::ConstValueIterator itr = update["values"].Begin();
+         itr != update["values"].End(); ++itr) {
       updateItem(*itr, sfixtime, temp_data);
     }
   }
 }
 
-void CommDecoder::updateItem(const rapidjson::Value &item,
-                             wxString &sfixtime, NavData& temp_data) {
+void CommDecoder::updateItem(const rapidjson::Value& item, wxString& sfixtime,
+                             NavData& temp_data) {
   bool bposValid = false;
   if (item.HasMember("path") && item.HasMember("value")) {
-    const wxString &update_path = item["path"].GetString();
+    const wxString& update_path = item["path"].GetString();
 
     if (update_path == _T("navigation.gnss.methodQuality")) {
       // Record statically the GNSS status for this source in a hashmap
@@ -441,9 +439,8 @@ void CommDecoder::updateItem(const rapidjson::Value &item,
                /*bposValid &&*/ !item["value"].IsNull()) {
       updateNavigationCourseOverGround(item["value"], sfixtime, temp_data);
     } else if (update_path == _T("navigation.courseOverGroundMagnetic")) {
-    }
-    else if (update_path ==
-             _T("navigation.gnss.satellites"))  // From GGA sats in use
+    } else if (update_path ==
+               _T("navigation.gnss.satellites"))  // From GGA sats in use
     {
       updateGnssSatellites(item["value"], sfixtime, temp_data);
     } else if (update_path ==
@@ -451,13 +448,13 @@ void CommDecoder::updateItem(const rapidjson::Value &item,
     {
       updateGnssSatellites(item["value"], sfixtime, temp_data);
     } else if (update_path == _T("navigation.headingTrue")) {
-      if(!item["value"].IsNull())
+      if (!item["value"].IsNull())
         updateHeadingTrue(item["value"], sfixtime, temp_data);
     } else if (update_path == _T("navigation.headingMagnetic")) {
-      if(!item["value"].IsNull())
+      if (!item["value"].IsNull())
         updateHeadingMagnetic(item["value"], sfixtime, temp_data);
     } else if (update_path == _T("navigation.magneticVariation")) {
-      if(!item["value"].IsNull())
+      if (!item["value"].IsNull())
         updateMagneticVariance(item["value"], sfixtime, temp_data);
     } else {
       // wxLogMessage(wxString::Format(_T("** Signal K unhandled update: %s"),
@@ -466,8 +463,9 @@ void CommDecoder::updateItem(const rapidjson::Value &item,
   }
 }
 
-bool CommDecoder::updateNavigationPosition(
-    const rapidjson::Value &value, const wxString &sfixtime, NavData& temp_data) {
+bool CommDecoder::updateNavigationPosition(const rapidjson::Value& value,
+                                           const wxString& sfixtime,
+                                           NavData& temp_data) {
   if ((value.HasMember("latitude") && value["latitude"].IsDouble()) &&
       (value.HasMember("longitude") && value["longitude"].IsDouble())) {
     // wxLogMessage(_T(" ***** Position Update"));
@@ -479,27 +477,27 @@ bool CommDecoder::updateNavigationPosition(
   }
 }
 
-
-void CommDecoder::updateNavigationSpeedOverGround(
-    const rapidjson::Value &value, const wxString &sfixtime, NavData& temp_data){
+void CommDecoder::updateNavigationSpeedOverGround(const rapidjson::Value& value,
+                                                  const wxString& sfixtime,
+                                                  NavData& temp_data) {
   double sog_ms = value.GetDouble();
-  double sog_knot = sog_ms * 1.9438444924406;   // m/s to knots
+  double sog_knot = sog_ms * 1.9438444924406;  // m/s to knots
   // wxLogMessage(wxString::Format(_T(" ***** SOG: %f, %f"), sog_ms, sog_knot));
   temp_data.gSog = sog_knot;
 }
 
 void CommDecoder::updateNavigationCourseOverGround(
-  const rapidjson::Value &value, const wxString &sfixtime, NavData& temp_data) {
+    const rapidjson::Value& value, const wxString& sfixtime,
+    NavData& temp_data) {
   double cog_rad = value.GetDouble();
   double cog_deg = GEODESIC_RAD2DEG(cog_rad);
   // wxLogMessage(wxString::Format(_T(" ***** COG: %f, %f"), cog_rad, cog_deg));
   temp_data.gCog = cog_deg;
 }
 
-void CommDecoder::updateGnssSatellites(const rapidjson::Value &value,
-                                       const wxString &sfixtime,
+void CommDecoder::updateGnssSatellites(const rapidjson::Value& value,
+                                       const wxString& sfixtime,
                                        NavData& temp_data) {
-
   if (value.IsInt()) {
     if (value.GetInt() > 0) {
       temp_data.n_satellites = value.GetInt();
@@ -515,20 +513,20 @@ void CommDecoder::updateGnssSatellites(const rapidjson::Value &value,
   }
 }
 
-void CommDecoder::updateHeadingTrue(const rapidjson::Value &value,
-                                    const wxString &sfixtime,
+void CommDecoder::updateHeadingTrue(const rapidjson::Value& value,
+                                    const wxString& sfixtime,
                                     NavData& temp_data) {
   temp_data.gHdt = GEODESIC_RAD2DEG(value.GetDouble());
 }
 
-void CommDecoder::updateHeadingMagnetic(
-    const rapidjson::Value &value, const wxString &sfixtime,
-    NavData& temp_data) {
+void CommDecoder::updateHeadingMagnetic(const rapidjson::Value& value,
+                                        const wxString& sfixtime,
+                                        NavData& temp_data) {
   temp_data.gHdm = GEODESIC_RAD2DEG(value.GetDouble());
 }
 
-void CommDecoder::updateMagneticVariance(
-    const rapidjson::Value &value, const wxString &sfixtime,
-    NavData& temp_data) {
+void CommDecoder::updateMagneticVariance(const rapidjson::Value& value,
+                                         const wxString& sfixtime,
+                                         NavData& temp_data) {
   temp_data.gVar = GEODESIC_RAD2DEG(value.GetDouble());
 }
